#
# spec file for package python-pydicom
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define         oldpython python
Name:           python-pydicom
Version:        1.4.2
Release:        lp152.1.1
Summary:        Pure python package for DICOM medical file reading and writing
License:        MIT
URL:            https://github.com/darcymason/pydicom
Source:         https://files.pythonhosted.org/packages/source/p/pydicom/pydicom-%{version}.tar.gz
BuildRequires:  %{python_module pytest-runner}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildArch:      noarch
%ifpython2
Obsoletes:      %{oldpython}-dicom < %{version}
Provides:       %{oldpython}-dicom = %{version}
%endif
%python_subpackages

%description
pydicom is a pure python package for parsing DICOM files
into natural pythonic structures for further manipulation.
Modified datasets can be written again to DICOM format files.

DICOM is a standard (http://medical.nema.org) for communicating
medical images and related information such as reports
and radiotherapy objects.

%prep
%setup -q -n pydicom-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
export LANG=en_US.UTF-8
%pytest pydicom/tests

%files %{python_files}
%license LICENSE
%{python_sitelib}/*

%changelog
* Tue Mar 10 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.4.2:
  * no upstream changelog
* Tue Jul 23 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.3.0:
  * no upstream changelog
* Fri Mar  8 2019 John Vandenberg <jayvdb@gmail.com>
- Reinstate test unit test_code_file which appears to be stable now
- Use PyPI sdist as source
* Wed Jan  2 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.2.2:
  * more python 3.7 fixes
* Thu Nov  1 2018 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.2.0:
  * No obvious upstream changelog
- Drop python37.patch should be fixed upstream
* Thu Aug 30 2018 Tomáš Chvátal <tchvatal@suse.com>
- Disable test_code_file as it randomly fails in OBS
* Wed Aug 29 2018 tchvatal@suse.com
- Update to 1.1.0:
  * License is distributed
  * Various speed improvements
- Add patch to work with python 3.7:
  * python37.patch
* Mon Sep 11 2017 jengelh@inai.de
- Make package description neutral and compact it.
* Mon Sep 11 2017 toddrme2178@gmail.com
- Implement single-spec version
* Thu Oct 13 2016 toddrme2178@gmail.com
- Update to version 0.9.9
  + Major changes / enhancements
  * All dicom dictionaries updated (standard dictionary, UID
    dictionary, and private dictionaries)
  * Dicom commands also added to dictionary
  * Ability to work with DICOMDIR:  read_dicomdir() function and
    DicomDir class. Example file show_dicomdir.py file added to
    examples subdirectory.
  * codify.py: Produce python/pydicom source code from a dicom
    file.
  * a number of python 3 compatibility enhancements
  * setup.py uses ez_setup only if setuptools not already
    installed
  * exceptions carry tag info with them, to aid in debugging
  + Contrib file changes
  * pydicom_series:  force parameter added (Nil Goyette)
  * dcm_qt_tree: switch to OrderedDict to preserve ordering of
    tags (Padraig Looney)
- Rename package to python-dicom to python-pydicom to conform to python
  package naming policies.
- spec file completely rewritten.
- Remove unneeded python-dicom-remove-obsolete-distribute-support.patch
* Tue Dec 17 2013 p.drouand@gmail.com
- Update to version 0.9.8
  + No changelog available
- Add python-dicom-remove-obsolete-distribute-support.patch; setup
  script try to import setuptools from distribute
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Fri Aug 17 2012 scorot@free.fr
- fix build for SLE 11 x86_64
* Tue Aug  7 2012 toddrme2178@gmail.com
- Initial version
